@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2017-2019 Tobias Junghans <tobydox@veyon.io>
  *
- * This file is part of Veyon - http://veyon.io
+ * This file is part of Veyon - https://veyon.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -22,8 +22,7 @@
  *
  */
 
-#ifndef VARIANT_STREAM_H
-#define VARIANT_STREAM_H
+#pragma once
 
 #include <QDataStream>
 
@@ -32,7 +31,7 @@
 class VEYON_CORE_EXPORT VariantStream
 {
 public:
-	VariantStream( QIODevice* ioDevice );
+	explicit VariantStream( QIODevice* ioDevice );
 
 	QVariant read(); // Flawfinder: ignore
 
@@ -42,5 +41,3 @@ private:
 	QDataStream m_dataStream;
 
 } ;
-
-#endif
